﻿;-----------------------------------------------------------------------
; photobooth_breezeviewer.ahk
;-----------------------------------------------------------------------
; AutoHotKey script to run a slideshow using BreezeViewer when the
; photo booth is in standby mode. Left click or touch the screen to
; return to the photo booth ready screen.
; Usage: run this script, Breeze Viewer and the photo booth software.
; When the photo booth software goes into standby mode the slideshow
; will be displayed. Touch the screen to hide the slideshow and return
; the photo booth back to ready mode.
;
; AutoHotKey is free and can be downloaded from:
; http://www.autohotkey.com
;
; This script comes with no warranty or support whatsoever and may
; be freely copied or modified as required.
;
; Written by Chris Breeze, www.breezesys.com
;-----------------------------------------------------------------------

#NoEnv  ; Recommended for performance and compatibility with future AutoHotkey releases.
#SingleInstance force
SendMode Input  ; Recommended for new scripts due to its superior speed and reliability.
SetWorkingDir %A_ScriptDir%  ; Ensures a consistent starting directory.
SetTitleMatchMode,2

; loop forever monitoring the status of the photobooth screen
Loop
{
	IfWinExist, Breeze Systems Photobooth
	{
		; photo booth software is running in full screen mode
		WinGetTitle, Title, Breeze Systems Photobooth
		if Title contains welcome.jpg
		{
			; photo booth is in standby - display slideshow
			IfWinNotExist, BreezeViewer_Slideshow
			{
				WinShow,BreezeViewer_Slideshow
			}
			IfWinExist, BreezeViewer_Slideshow
			{
				; Breeze Viewer slideshow window found, make sure it is active
				IfWinNotActive, BreezeViewer_Slideshow
				{
					WinActivate, BreezeViewer_Slideshow
				}
			}
			else
			{
				; Breeze Viewer slideshow window not found - press "Run" button in Breeze Viewer window
				WinShow,Breeze Viewer v
				IfWinExist, Breeze Viewer v
				{
					ControlClick,Run,Breeze Viewer v
					Sleep,1000
					WinHide,Breeze Viewer v
				}
			}
		}
		else
		{
			; photo booth is not in standby mode - hide slideshow window
			IfWinNotActive, Breeze Systems Photobooth
			{
				WinHide,Breeze Viewer v
				WinHide,BreezeViewer_Slideshow
				WinActivate, Breeze Systems Photobooth
			}
		}
	}
	else
	{
		; photo booth software not running in full sreen mode - close slideshow window
		ControlSend,,{esc}, BreezeViewer_Slideshow
		WinShow,Breeze Viewer v
		WinShow,BreezeViewer_Slideshow
		ControlSend,,{esc}, BreezeViewer_Slideshow
		Sleep,1000
	}
	Sleep 100	; sleep for 1/10th sec to avoid hogging the processor
}
Return

; Click left mouse button to exit the slideshow and return to photo booth ready screen
; Add extra keyboard macros here if required
#IfWinActive, BreezeViewer_Slideshow
LButton::
WinGetTitle, Title, Breeze Systems Photobooth
if Title contains welcome.jpg
{
	ControlSend,,{F6},Breeze Systems Photobooth
	WinHide,Breeze Viewer v
	WinHide,BreezeViewer_Slideshow
	WinActivate,Breeze Systems Photobooth
	Sleep,1000
}
else
{
	click
}
return
