﻿;---------------------------------------------------------------------------
; AutoHotkey script to change the camera settings when switching between
; stills and video photobooth modes in DSLR Remote Pro for Windows.
; The script is intended to be used with continuous lighting for video and
; flash for stills. "External flash mode" should be enabled in the photobooth
; settings dialog.
;
; AutoHotKey is free and can be downloaded from:
; http://www.autohotkey.com
;
; This script comes with no warranty or support whatsoever and may
; be freely copied or modified as required.
;
; Written by Chris Breeze, www.breezesys.com
;---------------------------------------------------------------------------

; Edit these values to give the correct exposure in live view in stills mode
; Note: when the photo is taken the shutter speed will be set to 1/200 sec
; Use "stills_Tv = bulb" to use auto exposure in live view for cameras that have
; bulb as a shutter speed setting as opposed to B as an exposure mode setting
; Set the value to 0 if you don't wnat it to change when switching to stills mode
stills_Tv = 1/4
stills_Av = 8.0
stills_ISO = 400

; Edit these values to give the correct exposure in live view in video mode
; Note: the video will be captured using these settings
; Use "video_ISO = Auto" for auto exposure
; Set the value to 0 if you don't wnat it to change when switching to video mode
video_Tv = 1/30
video_Av = 5.6
video_ISO = 3200

;**************** There's no need to edit anything below this line **********************

#NoEnv  ; recommended for performance and compatibility with future autohotkey releases.
#SingleInstance force
sendmode input  ; recommended for new scripts due to its superior speed and reliability.
setworkingdir %a_scriptdir%  ; ensures a consistent starting directory.
settitlematchmode, 1

ComboBox_Tv = ComboBox1
ComboBox_Av = ComboBox2
ComboBox_ISO = ComboBox4

loop
{
	IfWinExist, Breeze Systems Photobooth
	{
		WinGetTitle, title, Breeze Systems Photobooth
		if title <> %previoustitle%
		{
			; screen has changed
			if title contains \video_ready,\video_countdown
			{
				; booth has just switched to video ready screen
				Sleep, 1000	; wait for camera to finish switching to video mode before changing settings
				SetCombo(video_ISO, ComboBox_ISO)
				SetCombo(video_Tv, ComboBox_Tv)
				SetCombo(video_Av, ComboBox_Av)
			}
			else if title contains \ready,\1.jpg
			{
				; booth has just switched to stills ready screen
				SetCombo(stills_ISO, ComboBox_ISO)
				SetCombo(stills_Tv, ComboBox_Tv)
				SetCombo(stills_Av, ComboBox_Av)
			}
		}
		previoustitle := title
	}
	else
	{
		previoustitle :=
	}
	sleep 100	; sleep for 1/10th sec to avoid hogging the processor
}

; helper function to set the value of a combo box
SetCombo(value, combo)
{
	; do nothing if value=0
	if value = 0
	{
		return
	}

	ControlGetText, setting, %combo%, DSLR Remote Pro for Windows
	if setting <> value
	{
		Control, ChooseString, %value%, %combo%, DSLR Remote Pro for Windows
		ControlGetText, setting, %combo%, DSLR Remote Pro for Windows
		counter := 0
		while setting <> value
		{
			counter++
			if counter > 10
			{
				return
			}
			Sleep, 250
			Control, ChooseString, %value%, %combo%, DSLR Remote Pro for Windows
			ControlGetText, setting, %combo%, DSLR Remote Pro for Windows
		}
	}
}
